@@ -415,9 +415,9 @@ class NaroNet:
                                     # Save stats
                                     bar_epochs.update(1)
                                     bar_train_acc.update(-bar_train_acc.last_print_n+100*self.dict_epoch['train_acc'][-1][-1])
-                                    cont_loss = (100*self.dict_epoch['train_contrast_loss_Ph_loss'][-1][-1]+100*self.dict_epoch['train_contrast_loss_Nb_loss'][-1][-1]+100*self.dict_epoch['train_contrast_loss_Ph_loss'][-1][-1])/3
-                                    ent_loss = (100*self.dict_epoch['train_patch_entropy_Ph_loss'][-1][-1]+100*self.dict_epoch['train_patch_entropy_Nb_loss'][-1][-1]+100*self.dict_epoch['train_patch_entropy_Ar_loss'][-1][-1])/3
-                                    bar_contrast_acc.update(-bar_contrast_acc.last_print_n-cont_loss)
+                                    cont_loss = (self.dict_epoch['train_contrast_loss_Ph_loss'][-1][-1]+self.dict_epoch['train_contrast_loss_Nb_loss'][-1][-1]+self.dict_epoch['train_contrast_loss_Ph_loss'][-1][-1])/3
+                                    ent_loss = (self.dict_epoch['train_patch_entropy_Ph_loss'][-1][-1]+self.dict_epoch['train_patch_entropy_Nb_loss'][-1][-1]+self.dict_epoch['train_patch_entropy_Ar_loss'][-1][-1])/3
+                                    bar_contrast_acc.update(-bar_contrast_acc.last_print_n+cont_loss)
                                     patch_entropy_acc.update(-patch_entropy_acc.last_print_n+ent_loss)                                                                        
                                 
                                 # Test Model
