@@ -2,85 +2,99 @@ import torch
 import numpy as np
 import torch
 import torch.nn.functional as F
+import gc
 
-def calc_contrast_loss(features,assignment_orig,device):
-
+def calc_contrast_loss_prev(features,assignment_orig,device,args):
+    '''
+    Maximize contrast of top1 patches and their neighbors.
+    
+    '''
     # Use a batch size of 1000
-    nbatch = max(min(50,int(assignment_orig.shape[0]/assignment_orig.shape[1]*0.01),assignment_orig.shape[0]),assignment_orig.shape[1])
-    n_neighb = 100
+    # TOP 1%
+    # K_top = max(min(int(assignment_orig.shape[0]*0.01/assignment_orig.shape[1]),assignment_orig.shape[0]),assignment_orig.shape[1])
+    # n_batch = min(100,K_top)
+    # n_neighb = min(50,assignment_orig.shape[0])
+    # TOP 1
+    K_top = 1
+    n_batch = max(min(int(assignment_orig.shape[0]*args['Perc_high_conf_patches']*2),assignment_orig.shape[0]),10,assignment_orig.shape[1])
+    neg_batch = min(10000,assignment_orig.shape[0])
 
     # Calculate feature similarities
     features = F.normalize(features.squeeze(), dim=1)    
+    assignment_orig = F.normalize(assignment_orig,dim=1)
     temp = 0.07
 
     loss = 0
     for ph in range(assignment_orig.shape[1]):
-        sel_vals = assignment_orig[:,ph].topk(nbatch,0)[1]       
+        
+        # Positives
+        sel_vals = assignment_orig[:,ph].topk(K_top,0)[1]   
         feats = torch.matmul(features[sel_vals], features.T)        
-        top_elem = (feats.topk(n_neighb,1)[1]).reshape(100*nbatch)        
-        positives = torch.exp((torch.matmul(assignment_orig[top_elem],assignment_orig[top_elem].T)/temp))
-        loss += -torch.log(positives).mean()*temp
-        # print((assignment_orig[top_elem].argmax(1)==ph).sum()/top_elem.shape[0])
+        top_elem = (feats.topk(n_batch,1)[1]).squeeze()
+        positives = torch.exp((torch.matmul(assignment_orig[top_elem],assignment_orig[top_elem].T)/temp))        
 
+        # Negatives
+        sel_vals_neg = torch.randint(0, assignment_orig.shape[0]-1, (neg_batch,))
+        negatives = torch.exp((torch.matmul(assignment_orig[top_elem],assignment_orig[sel_vals_neg].T)/temp))        
+        loss += -torch.log(positives).mean()*temp
+        loss += torch.log(negatives).mean()*temp
+        
     return loss/assignment_orig.shape[1]
 
 
-# def calc_contrast_loss(features,assignment_orig,device):
+def calc_contrast_loss(features,assignment_orig,device,args):
 
-#     # Use a batch size of 1000
-#     nbatch = max(min(5,assignment_orig.shape[0]),assignment_orig.shape[1])
-#     sel_vals = assignment_orig.topk(nbatch,0)[1].reshape(nbatch*assignment_orig.shape[1])
 
-#     # Calculate feature similarities
-#     features = F.normalize(features[sel_vals].squeeze(), dim=1)
-#     features = torch.matmul(features, features.T)
- 
-#     # Find top-1
-#     features[torch.eye(features.shape[0], dtype=torch.bool).to(device)] = 0
-#     top_elem = features.topk(1,1)[1]
-#     #low_elem = features.topk(1,1,largest=False)[1]
-
-#     # Calculate assignment similarities  
-#     assignment = assignment_orig[sel_vals].squeeze().clone()
-#     bound = assignment.max(1,True)[0]
-#     assignment[assignment != bound] = 0  # set the values i want to keep to 1
-#     # assignment[assignment == bound] = 1            
-
-#     # Contrast 
-#     temp = 0.07
-#     positives = torch.exp((assignment*assignment[top_elem.squeeze(),:]).sum(1)/temp)
-#     #negatives = torch.exp((assignment*assignment[torch.randint(0,assignment.shape[0],(assignment.shape[0],1)).squeeze(),:]).sum(1)/temp)
-
-#     # # Accuracy
-#     # pos = torch.eq(assignment.argmax(1),assignment[top_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]
-#     # neg = torch.eq(assignment.argmax(1),assignment[low_elem.squeeze(),:].argmax(1)).sum()/assignment.shape[0]    
+    # Number of patches that define the phenotype.
+    K_top = 1 
     
-#     return -torch.log(positives).mean()*temp
+    # Number of patches going to 
+    pos_batch = max(min(int(assignment_orig.shape[0]*args['Perc_high_conf_patches']),assignment_orig.shape[0]),4,assignment_orig.shape[1])
 
-# def calc_contrast_loss(features,assignment_orig,device):
+    # Calculate feature similarities
+    features = F.normalize(features.squeeze(), dim=1)    
+    assignment_orig = F.normalize(assignment_orig,dim=1)
+    temp = 0.07
 
-#     # Use a batch size of 1000
-#     nbatch = max(min(int(assignment_orig.shape[0]/assignment_orig.shape[1]*0.001),assignment_orig.shape[0]),assignment_orig.shape[1])
+    loss = 0
+    for ph in range(assignment_orig.shape[1]):
+        
+        # Perfect assignment
+        objective = torch.zeros(assignment_orig.shape[1],device=device)
+        objective[ph] = 1
 
-#     features = F.normalize(features.squeeze(), dim=1)
-    
-#     # Calculate entropy loss
-#     loss = 0
-#     for ph in range(assignment_orig.shape[1]):
+        # Obtain top-k assignment that defines the TME
+        top_assignment = assignment_orig[:,ph].topk(K_top,0)[1]   
+        
+        # Feature distance to top-k
+        feat_dist = torch.matmul(features[top_assignment], features.T)        
+        
+        # Select most similar patches
+        top_elem = (feat_dist.topk(pos_batch,1)[1]).squeeze()
+        
+        # Positive loss - patches with similar features to the top-k patches should have the same assignment
+        positives = torch.exp((torch.matmul(objective,assignment_orig[top_elem].T)/temp)) 
+        loss += -torch.log(positives).mean()*temp       
 
-#         sel_vals = assignment_orig[:,ph].topk(nbatch,0)[1]        
-                        
-#         loss += -torch.log(torch.exp(torch.matmul(features[sel_vals], features[sel_vals].T)/0.07)).mean()
-   
-#     return loss/assignment_orig.shape[1]
+        # # Patches with highest confidence assignment 
+        # highest_conf_assignment = assignment_orig[:,ph].topk(pos_batch*10,0)[1]   
+        
+        # # Patch with highest features distance from top-1
+        # bottom_val = feat_dist[:,highest_conf_assignment].topk(pos_batch,1,largest=False)[1].squeeze()
+        
+        # # Negative loss - patches with dissimilar features to the top-k patches but with high assignment confidence should have a dissimilar assignment.
+        # negatives = torch.exp((torch.matmul(objective,assignment_orig[highest_conf_assignment[bottom_val]].T)/temp))        
+        # loss += (torch.log(negatives)*(1-feat_dist[0,highest_conf_assignment[bottom_val]])/2).mean()*temp
+        
+    return loss/assignment_orig.shape[1]
 
 def calc_patch_ent(s,device):    
     return ((-s/s.sum(dim=-1,keepdim=True) * torch.log(s/s.sum(dim=-1,keepdim=True) + 1e-15)).sum(dim=-1)/torch.log(torch.tensor(s.shape[1],dtype=torch.float32,device=device))).mean()   
 
-def patch_contrast_entropy(x, s, num_nodes, device):
+def patch_contrast_entropy(x, s, num_nodes, device,args):
     
     # Calculate contrast acc        
-    contrast_loss = calc_contrast_loss(torch.cat([x[i,:num_nodes[i],:] for i in range(s.shape[0])]), torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)          
+    contrast_loss = calc_contrast_loss(torch.cat([x[i,:num_nodes[i],:] for i in range(s.shape[0])]), torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device,args)          
     
     # Calculate Patch Entropy
     PatchEntropy_loss = calc_patch_ent(torch.cat([s[i,:num_nodes[i],:] for i in range(s.shape[0])]),device)                     
