@@ -14,24 +14,23 @@ def parameters(path, debug):
     if 'STK11' in path:            
         
         # Patch contrastive learning parameters
-        args['PCL_CNN_Architecture']='resnet50' # or resnet18
-        args['PCL_N_Workers']=1 # Number of data loading workers 
-        args['PCL_Epochs']=100 # Number of total epoch to run
-        args['PCL_N_Crops_per_Image']=110 # Number of crops chosen per image
-        args['PCL_Patch_Size']=30 # Size of patches in pixels
-        args['PCL_Stride']=0 # Size of stride between consecutive patches
-        args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
-        args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
-        args['PCL_Batch_Size']= 4 # Number of images per iteration
-        args['PCL_Weight_Decay']= 1e-4 # Weight Decay
-        args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
-        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
-        args['PCL_Temperature']= 0.07 # Softmax temperature                
-        args['PCL_eliminate_Black_Background'] = True
-        args['PCL_eliminate_White_Background'] = False
-        args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
-        args['PCL_Color_perturbation_Augmentation'] = False # Color augmentation for H&E tissue staining.
-
+        args['PCL_CNN_Architecture']='resnet50' # Architecture of the CNN. Choose between resnet50 or resnet18. resnet50 is slow but is capable of learning more complex patterns. resnet18 is faster but learns simpler patterns. So far we have used resnet50.
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate used to train the CNN. Do not change this value.
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay used to train the CNN. Do not change this value.
+        args['PCL_Temperature']= 0.07 # Softmax temperature used to train the CNN. Do not change this value.
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # Specify the GPU where the training is carried out.
+        args['PCL_Epochs']=200 # Number of epochs to run PCL. Increase the numnber so that PCL achieves at least a 85% of top1 accuracy.
+        args['PCL_N_Workers']=1 # Number of workers to parallelize data loading. A higher number of workers will result in a faster execution but will require more RAM memory usage. 
+        args['PCL_N_Crops_per_Image']=300 # Number of image crops used to train the model in each iteration. Higher number of crops will learn more features from patches from one image but requires more RAM and GPU memory usage.
+        args['PCL_Patch_Size']=30 # Size of image patch (in pixels). We saw best performance when the patch embeds 1 to 3 cells.
+        args['PCL_Stride']=0 # Size of stride between consecutive patches. Do not use it. It is not yet implemented. :(
+        args['PCL_Alpha_L']=1.15 # Size ratio between image crop and image patch. Check paper for better explanation.
+        args['PCL_Z_Score']= True # Whether to apply z_score per channel/marker. Seen better performance when using it. 
+        args['PCL_Batch_Size']= 4 # Number of images used per iteration. A higher batch size results in learning more features and doing it in a more stable way but will require more RAM and GPU memory usage.    
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of the output image patch. A higher value results in more learned features but requires more RAM and GPU memory usage.
+        args['PCL_eliminate_Black_Background'] = True # Whether to eliminate from the training the black background. Use it for Multiplex fluorescence images.
+        args['PCL_eliminate_White_Background'] = False # Whether to eliminate from the training the whit background. Use it for H&E white-field microscopy images.        
+        args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
 
         # Label you want to infer with respect the images.
         args['experiment_Label'] = ['Mutation'] 
@@ -41,12 +40,12 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,500]) if debug=='Object' else 500
+        args['epochs'] = 3 if debug=='Index' else hp.choice('epochs',[6,15,30,400]) if debug=='Object' else 400
         args['lr_decay_factor'] = 0.25# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 11000#max(int(args['epochs']/2),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
-        args['batch_size'] = 4 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 14, 24]) if debug=='Object' else 24
-        args['lr'] = 0 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 1
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 12, 25]) if debug=='Object' else 12
+        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.01
 
         # General
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -54,10 +53,10 @@ def parameters(path, debug):
         args['device'] = 'cuda:0'
         args['Batch_Normalization'] = True
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
-
+            
         # Neural Network
-        args['N_Phenotypes'] = 0 if debug=='Index' else hp.choice('clusters1',[8,10,15,20]) if debug=='Object' else 8     
-        args['N_Neighborhoods'] = 2 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 16
+        args['N_Phenotypes'] = 0 if debug=='Index' else hp.choice('clusters1',[8,10,15,20]) if debug=='Object' else 8   
+        args['N_Neighborhoods'] = 1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 16
         args['N_Areas'] = 1 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 4      
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
@@ -67,29 +66,29 @@ def parameters(path, debug):
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
         
         # Losses
-        args['ContrastACC_Pheno'] = 10# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
-        args['ContrastACC_Neigh'] = 10# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
+        args['ContrastACC_Pheno'] = 100# if debug=='Index' else hp.choice("ContrastACC_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.01
+        args['ContrastACC_Neigh'] = 100# if debug=='Index' else hp.choice("ContrastACC_Neigh", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 1
         args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("ContrastACC_Area", [1, 0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001
         args['PatchEntropy_Pheno'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Pheno", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1   
         args['PatchEntropy_Neigh'] = 0#1 if debug=='Index' else hp.choice("PatchEntropy_Neigh", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.1
-        args['PatchEntropy_Area'] = 0#4 if debug=='Index' else hp.choice("PatchEntropy_Area", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001                                             
+        args['PatchEntropy_Area'] = 1#4 if debug=='Index' else hp.choice("PatchEntropy_Area", [1,0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001                                             
 
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
-        args['TSNE_Perc_Pat'] = 0.5 # Percentage of patients to use to generate the tsne. 
+        args['TSNE_Perc_Pat'] = 0 # Percentage of patients to use to generate the tsne.     
 
 
     elif 'Melanoma_ProgressionvsBaseline' in path:            
         # Patch contrastive learning parameters
         args['PCL_CNN_Architecture']='resnet50' # or resnet18
-        args['PCL_N_Workers']=0 # Number of data loading workers 
-        args['PCL_Epochs']=60 # Number of total epoch to run
-        args['PCL_N_Crops_per_Image']=70 # Number of crops chosen per image
+        args['PCL_N_Workers']=2 # Number of data loading workers 
+        args['PCL_Epochs']=300 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=300 # Number of crops chosen per image
         args['PCL_Patch_Size']=50 # Size of patches in pixels
         args['PCL_Stride']=0 # Size of stride between consecutive patches
         args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
         args['PCL_Z_Score']= True # Whether to apply z score per channel/marker 
-        args['PCL_Batch_Size']= 5 # Number of images per iteration
+        args['PCL_Batch_Size']= 6 # Number of images per iteration
         args['PCL_Weight_Decay']= 1e-4 # Weight Decay
         args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
         args['PCL_Learning_Rate']= 0.0003 # Learning Rate
@@ -100,18 +99,19 @@ def parameters(path, debug):
         args['PCL_Color_perturbation_Augmentation'] = True # Color augmentation for H&E tissue staining.
 
         # Label you want to infer with respect the images.
-        args['experiment_Label'] = ['Sample_type'] 
+        args['experiment_Label'] = ['Sample_Type'] 
 
         # Architecture Search parameters
         args['num_samples_architecture_search'] = 700  
 
         # Optimization Parameters
-        args['epochs'] = 80# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['NaroNet_n_workers'] = 1 # Number of data loading workers
+        args['epochs'] = 400# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/3),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 0#3 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0.0001
-        args['batch_size'] = 4 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 16, 28]) if debug=='Object' else 28
-        args['lr'] = 1 if debug=='Index' else hp.choice('lr', [1,0.5,0.01,0.001,0.0001]) if debug=='Object' else 0.5
+        args['batch_size'] = 4 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 16, 32]) if debug=='Object' else 32
+        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.01
 
         # General        
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.            
@@ -122,8 +122,8 @@ def parameters(path, debug):
 
         # Neural Network
         args['N_Phenotypes'] = 1 if debug=='Index' else hp.choice('clusters1',[5,8,15,20]) if debug=='Object' else 8     
-        args['N_Neighborhoods'] = 2 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 16 
-        args['N_Areas'] = 1 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 4      
+        args['N_Neighborhoods'] = 2 if debug=='Index' else hp.choice('clusters2',[6,11,12,21]) if debug=='Object' else 12
+        args['N_Areas'] = 1 if debug=='Index' else hp.choice('clusters3',[2,6,7]) if debug=='Object' else 6      
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True  
         args['Area_Learning'] = True
@@ -132,15 +132,18 @@ def parameters(path, debug):
         args['1Patch1Cluster'] = True# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
 
         # Losses 
-        args['ContrastACC_Pheno'] = 1#.001#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
-        args['ContrastACC_Neigh'] = 1#.001#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
-        args['ContrastACC_Area'] = 1#.0001#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Pheno'] = 100#.001#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 100#.001#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 100#.0001#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001            
+        args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. A low values generates rare populations.                                  
         args['PatchEntropy_Pheno'] = 0#.01#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
         args['PatchEntropy_Neigh'] = 0#.01#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
         args['PatchEntropy_Area'] = 0#.0001#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1                                  
 
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
+        args['TSNE_Perc_Pat'] = 0.33 # Percentage of patients to use to generate the tsne. 
+
 
     elif 'LF_Recurrence' in path:            
         # Patch contrastive learning parameters
@@ -286,10 +289,11 @@ def parameters(path, debug):
         args['PCL_Batch_Size']= 8 # Number of images per iteration
         args['PCL_Weight_Decay']= 1e-4 # Weight Decay
         args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
-        args['PCL_Learning_Rate']= 0.003 # Learning Rate
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
         args['PCL_Temperature']= 0.07 # Softmax temperature    
-        args['PCL_eliminate_Black_Background'] = False
+        args['PCL_eliminate_Black_Background'] = True 
         args['PCL_eliminate_White_Background'] = False            
+        args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
         args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
 
         # Label you want to infer with respect the images.
@@ -300,12 +304,12 @@ def parameters(path, debug):
 
         # Optimization Parameters
         args['NaroNet_n_workers'] = 1
-        args['epochs'] = 1000# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['epochs'] = 100# if debug else hp.quniform('epochs', 5, 25, 1)
         args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
         args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
         args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
         args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
-        args['lr'] = 2 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.01
+        args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
 
         # General
         args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
@@ -315,8 +319,8 @@ def parameters(path, debug):
         args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
 
         # Neural Network
-        args['N_Phenotypes'] = 8#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
-        args['N_Neighborhoods'] = 10#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Phenotypes'] = 6#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 8#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
         args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
         args['Phenotype_Learning'] = True  
         args['Neighborhood_Learning'] = True
@@ -326,16 +330,85 @@ def parameters(path, debug):
         args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
                 
         # Losses
-        args['ContrastACC_Pheno'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
-        args['ContrastACC_Neigh'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
-        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Pheno'] = 1000#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 1000#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001 
+        args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
         args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
         args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
         args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
         
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = True
-        args['TSNE_Perc_Pat'] = 0.75 # Percentage of patients to use to generate the tsne. 
+        args['TSNE_Perc_Pat'] = 1 # Percentage of patients to use to generate the tsne. 
+
+
+    elif 'Endometrial_Survival' in path:            
+        
+        # Patch contrastive learning parameters
+        args['PCL_CNN_Architecture']='resnet50' # or resnet18
+        args['PCL_N_Workers']=8 # Number of data loading workers 
+        args['PCL_Epochs']=80 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=30 # Number of crops chosen per image
+        args['PCL_Patch_Size']=15 # Size of patches in pixels
+        args['PCL_Stride']=0 # Size of stride between consecutive patches
+        args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
+        args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
+        args['PCL_Batch_Size']= 40 # Number of images per iteration
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
+        args['PCL_Temperature']= 0.07 # Softmax temperature    
+        args['PCL_eliminate_Black_Background'] = False 
+        args['PCL_eliminate_White_Background'] = False        
+        args['PCL_Color_perturbation_Augmentation'] = False # Whether to use color normalization augmentation in H&E white-field microscopy images. Used to force PCL to learn morphological features and avoid learning color staining features. 
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
+
+        # Label you want to infer with respect the images.
+        args['experiment_Label'] = ['POLE Mutation'] 
+
+        # Architecture Search parameters
+        args['num_samples_architecture_search'] = 1500  
+
+        # Optimization Parameters
+        args['NaroNet_n_workers'] = 1
+        args['epochs'] = 300# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
+        args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
+        args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
+        args['lr'] = 3 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 0.001
+
+        # General
+        args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
+        args['folds'] = 1
+        args['device'] = 'cuda:0'
+        args['Batch_Normalization'] = True
+        args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
+
+        # Neural Network
+        args['N_Phenotypes'] = 4#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 6#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Areas'] = 2#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['Phenotype_Learning'] = True  
+        args['Neighborhood_Learning'] = True
+        args['Area_Learning'] = True
+        args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
+        args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
+        args['1Patch1Cluster'] = False# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
+                
+        # Losses
+        args['ContrastACC_Pheno'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001 
+        args['Perc_high_conf_patches'] = 0.001 # 1 is 100%. Great values generates phenotypes and neighborhoods with many patches. Low values generate rare populations.
+        args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
+        args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
+        args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
+        
+        # Bioinsights parameters
+        args['Bio_save_Orig_im'] = True
+        args['TSNE_Perc_Pat'] = 1 # Percentage of patients to use to generate the tsne. 
 
     elif 'Tumor_subtype' in path:            
         
@@ -399,6 +472,72 @@ def parameters(path, debug):
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
 
+    elif 'Melanoma_ProgressionvsBaseline' in path:            
+        
+        # Patch contrastive learning parameters
+        args['PCL_CNN_Architecture']='resnet50' # or resnet18
+        args['PCL_N_Workers']=1 # Number of data loading workers 
+        args['PCL_Epochs']=300 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=200 # Number of crops chosen per image
+        args['PCL_Patch_Size']=50 # Size of patches in pixels
+        args['PCL_Stride']=0 # Size of stride between consecutive patches
+        args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
+        args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
+        args['PCL_Batch_Size']= 4 # Number of images per iteration
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
+        args['PCL_Learning_Rate']= 0.0003 # Learning Rate
+        args['PCL_Temperature']= 0.07 # Softmax temperature                
+        args['PCL_eliminate_Black_Background'] = False
+        args['PCL_eliminate_White_Background'] = True
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
+        args['PCL_Color_perturbation_Augmentation'] = True # Color augmentation for H&E tissue staining.
+
+        # Label you want to infer with respect the images.
+        args['experiment_Label'] = ['Sample_Type'] 
+
+        # Architecture Search parameters
+        args['num_samples_architecture_search'] = 1500  
+
+        # Optimization Parameters
+        args['NaroNet_n_workers'] = 1
+        args['epochs'] = 1000
+        args['lr_decay_factor'] = 0.1
+        args['lr_decay_step_size'] = 10000
+        args['weight_decay'] = 0
+        args['batch_size'] = 24
+        args['lr'] = 0.001 
+
+        # General
+        args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
+        args['folds'] = 1
+        args['device'] = 'cuda:0'
+        args['Batch_Normalization'] = True
+        args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
+
+        # Neural Network
+        args['N_Phenotypes'] = 6#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 8#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['Phenotype_Learning'] = True  
+        args['Neighborhood_Learning'] = True
+        args['Area_Learning'] = True
+        args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
+        args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
+        args['1Patch1Cluster'] = False
+                
+        # Losses
+        args['ContrastACC_Pheno'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 100#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 0#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['PatchEntropy_Pheno'] = 0#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
+        args['PatchEntropy_Neigh'] = 0#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
+        args['PatchEntropy_Area'] = 0#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
+        
+        # Bioinsights parameters
+        args['Bio_save_Orig_im'] = False
+        args['TSNE_Perc_Pat'] = 0.5 # Percentage of patients used to calculate TSNE. 1 is 100% of patients
+
     else:
         
         # Patch contrastive learning parameters
